All Classes and Interfaces

Class
Description
Abstract converter for Java Number types.
Converter for the Java BigDecimal type.
Converter for the Java BigInteger type.
Converter for the Java Boolean type.
Buffered reader that can wrap another reader and count the lines read.
Converter for the Java Byte type.
Converter for the Java String type.
Information about a particular CSV column used internally to keep track of the CSV columns.
Definition of a class which compares column names to see if they match.
Converts from a textual representation to a Java representation.
Manages the collection of converter objects so we can reuse them as necessary.
Annotation to be added to a field or method to mark it as a column in a CSV file.
Deprecated.
Should switch to CsvColumn which makes more send with get/set method support.
CSV reader and writer.
Converter for the Java java.util.Date type which uses the SimpleDateFormat -- don't worry I protect it for reentrance.
Converter for the Java Double type.
Converter for the Java Enum type associated with an Enum field.
Converter for the Java Float type.
Converter for the Java Integer type.
Converter for the Java Long type.
Used to report back with any parsing or internal errors.
The type of the error.
Row validator callback that can be registered with the CsvProcessor.setRowValidator(RowValidator) that validates the entity _after_ it has been parsed from the CSV line.
Converter for the Java Short type.
Converter for the Java String type.
Converter for the Java UUID type.
Place holder so we can configure the fields with a default converter.