Package com.j256.simplecsv.processor
package com.j256.simplecsv.processor
Classes used to process CSV files.
-
ClassDescriptionBuffered reader that can wrap another reader and count the lines read.ColumnInfo<T>Information about a particular CSV column used internally to keep track of the CSV columns.Definition of a class which compares column names to see if they match.CsvProcessor<T>CSV reader and writer.Used to report back with any parsing or internal errors.The type of the error.RowValidator<T>Row validator callback that can be registered with the
CsvProcessor.setRowValidator(RowValidator)that validates the entity _after_ it has been parsed from the CSV line.