Index
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form
A
- AbstractNumberConverter<T> - Class in com.j256.simplecsv.converter
-
Abstract converter for Java Number types.
- AbstractNumberConverter() - Constructor for class com.j256.simplecsv.converter.AbstractNumberConverter
- addInternalConverters(Map) - Static method in class com.j256.simplecsv.converter.ConverterUtils
-
Add internal converters to the map.
- afterColumn() - Element in annotation type com.j256.simplecsv.common.CsvColumn
-
Used to set the order of the columns by setting the column-name that this column comes after.
B
- BigDecimalConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java BigDecimal type.
- BigDecimalConverter() - Constructor for class com.j256.simplecsv.converter.BigDecimalConverter
- BigIntegerConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java BigInteger type.
- BigIntegerConverter() - Constructor for class com.j256.simplecsv.converter.BigIntegerConverter
- BLANK_IS_NULL - Static variable in class com.j256.simplecsv.converter.StringConverter
-
If enabled, a blank string will be interpreted as a null value.
- BooleanConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java Boolean type.
- BooleanConverter() - Constructor for class com.j256.simplecsv.converter.BooleanConverter
- BufferedReaderLineCounter - Class in com.j256.simplecsv.processor
-
Buffered reader that can wrap another reader and count the lines read.
- BufferedReaderLineCounter(Reader) - Constructor for class com.j256.simplecsv.processor.BufferedReaderLineCounter
- buildHeaderLine(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Build and return a header string made up of quoted column names.
- buildLine(T, boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Convert the entity into a string of column values.
- ByteConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java Byte type.
- ByteConverter() - Constructor for class com.j256.simplecsv.converter.ByteConverter
C
- CASE_SENSITIVE - Static variable in class com.j256.simplecsv.converter.BooleanConverter
-
Set this flag using
CsvColumn.converterFlags()if you want the boolean formats to be compared case-sensitively. - CharacterConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java String type.
- CharacterConverter() - Constructor for class com.j256.simplecsv.converter.CharacterConverter
- ColumnInfo<T> - Class in com.j256.simplecsv.processor
-
Information about a particular CSV column used internally to keep track of the CSV columns.
- columnName() - Element in annotation type com.j256.simplecsv.common.CsvColumn
-
This allows you to override and set a column name.
- columnName() - Element in annotation type com.j256.simplecsv.common.CsvField
-
Deprecated.This allows you to override and set a column name for the field.
- ColumnNameMatcher - Interface in com.j256.simplecsv.processor
-
Definition of a class which compares column names to see if they match.
- com.j256.simplecsv.common - package com.j256.simplecsv.common
-
Common classes used to define CSV entities.
- com.j256.simplecsv.converter - package com.j256.simplecsv.converter
-
Classes which deal with the converting of strings to Java fields and back.
- com.j256.simplecsv.processor - package com.j256.simplecsv.processor
-
Classes used to process CSV files.
- configure(String, long, ColumnInfo) - Method in class com.j256.simplecsv.converter.BooleanConverter
- configure(String, long, ColumnInfo) - Method in class com.j256.simplecsv.converter.CharacterConverter
- configure(String, long, ColumnInfo) - Method in class com.j256.simplecsv.converter.EnumConverter
- configure(String, long, ColumnInfo) - Method in class com.j256.simplecsv.converter.StringConverter
- configure(String, long, ColumnInfo) - Method in class com.j256.simplecsv.converter.VoidConverter
- configure(String, long, ColumnInfo) - Method in class com.j256.simplecsv.converter.BigDecimalConverter
- configure(String, long, ColumnInfo) - Method in class com.j256.simplecsv.converter.BigIntegerConverter
- configure(String, long, ColumnInfo) - Method in class com.j256.simplecsv.converter.DateConverter
- configure(String, long, ColumnInfo) - Method in class com.j256.simplecsv.converter.UuidConverter
- configure(String, long, ColumnInfo) - Method in class com.j256.simplecsv.converter.AbstractNumberConverter
- configure(String, long, ColumnInfo) - Method in interface com.j256.simplecsv.converter.Converter
-
Configure this instance of the converter based on the associated params.
- constructConverter(Class) - Static method in class com.j256.simplecsv.converter.ConverterUtils
-
Construct a converter instance.
- Converter<T,
C> - Interface in com.j256.simplecsv.converter -
Converts from a textual representation to a Java representation.
- converterClass() - Element in annotation type com.j256.simplecsv.common.CsvColumn
-
Sets the converter to use to convert this column if you don't want to use the default appropriate internal class.
- converterClass() - Element in annotation type com.j256.simplecsv.common.CsvField
-
Deprecated.Sets the converter to use to convert this column if you don't want to use the default appropriate internal class.
- converterFlags() - Element in annotation type com.j256.simplecsv.common.CsvColumn
-
Optional flags for the converter which adjust the output.
- converterFlags() - Element in annotation type com.j256.simplecsv.common.CsvField
-
Deprecated.Optional flags for the converter which adjust the output.
- ConverterUtils - Class in com.j256.simplecsv.converter
-
Manages the collection of converter objects so we can reuse them as necessary.
- ConverterUtils() - Constructor for class com.j256.simplecsv.converter.ConverterUtils
- CsvColumn - Annotation Type in com.j256.simplecsv.common
-
Annotation to be added to a field or method to mark it as a column in a CSV file.
- CsvField - Annotation Type in com.j256.simplecsv.common
-
Deprecated.
- CsvProcessor<T> - Class in com.j256.simplecsv.processor
-
CSV reader and writer.
- CsvProcessor() - Constructor for class com.j256.simplecsv.processor.CsvProcessor
- CsvProcessor(Class) - Constructor for class com.j256.simplecsv.processor.CsvProcessor
-
Constructs a processor with an entity class whose fields should be marked with
CsvColumnannotations.
D
- DateConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java java.util.Date type which uses the
SimpleDateFormat-- don't worry I protect it for reentrance. - DateConverter() - Constructor for class com.j256.simplecsv.converter.DateConverter
- DEFAULT_COLUMN_QUOTE - Static variable in class com.j256.simplecsv.processor.CsvProcessor
-
Default quote character for columns to wrap them if they have special characters.
- DEFAULT_COLUMN_SEPARATOR - Static variable in class com.j256.simplecsv.processor.CsvProcessor
-
Default separator character for columns.
- DEFAULT_DATE_PATTERN - Static variable in class com.j256.simplecsv.converter.DateConverter
-
Default
SimpleDateFormatformat pattern used to read/write java.util.Date types. - DEFAULT_LINE_TERMINATION - Static variable in class com.j256.simplecsv.processor.CsvProcessor
-
Default line termination string to be written at the end of CSV lines.
- DEFAULT_VALUE - Static variable in annotation type com.j256.simplecsv.common.CsvColumn
-
Used internally to detect whether or not a value has been configured.
- DEFAULT_VALUE - Static variable in annotation type com.j256.simplecsv.common.CsvField
-
Deprecated.Used internally to detect whether or not a value has been configured.
- defaultValue() - Element in annotation type com.j256.simplecsv.common.CsvColumn
-
Set this to a default string for the column.
- defaultValue() - Element in annotation type com.j256.simplecsv.common.CsvField
-
Deprecated.Set this to a default string for the column.
- DoubleConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java Double type.
- DoubleConverter() - Constructor for class com.j256.simplecsv.converter.DoubleConverter
E
- EnumConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java Enum type associated with an Enum field.
- EnumConverter() - Constructor for class com.j256.simplecsv.converter.EnumConverter
F
- FloatConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java Float type.
- FloatConverter() - Constructor for class com.j256.simplecsv.converter.FloatConverter
- format() - Element in annotation type com.j256.simplecsv.common.CsvColumn
-
Sets the format for this column.
- format() - Element in annotation type com.j256.simplecsv.common.CsvField
-
Deprecated.Sets the format for this column.
- FORMAT_IS_UNKNOWN_VALUE - Static variable in class com.j256.simplecsv.converter.EnumConverter
-
If this flag is set then the
CsvColumn.format()string is actually the name of the enum constant that will be used if the value in the column is unknown. - forTests(Converter, Class, String, long) - Static method in class com.j256.simplecsv.processor.ColumnInfo
-
For testing purposes.
- fromAnnotation(CsvColumn, String, Class, Field, Method, Method, Converter) - Static method in class com.j256.simplecsv.processor.ColumnInfo
-
Make a column-info instance from a Java Field.
- fromAnnotation(CsvField, String, Class, Field, Method, Method, Converter) - Static method in class com.j256.simplecsv.processor.ColumnInfo
-
Make a column-info instance from a Java Field.
G
- getAfterColumn() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Column name that we come after to have the order not be field or method position based.
- getColumnName() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Returns the header name for this column.
- getColumnName() - Method in class com.j256.simplecsv.processor.ParseError
-
Return the name of the column that was affected, if any.
- getColumnType() - Method in class com.j256.simplecsv.processor.ParseError
-
Return the java class of the column, if any.
- getColumnValue() - Method in class com.j256.simplecsv.processor.ParseError
-
Return the value of the column that was being parsed, if any.
- getConfigInfo() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Returns the configuration information associated with the column, if any.
- getConverter() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Returns the converter class associated with the column.
- getDefaultValue() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Returns the default string for the column or null if none.
- getErrorType() - Method in class com.j256.simplecsv.processor.ParseError
-
Return the enumerated error type for this parse error.
- getField() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Associated reflection field or null if using get/set method.
- getFieldName() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Name of the java field or the get/set methods.
- getGetMethod() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Associated reflection get/is method or null if using field.
- getLine() - Method in class com.j256.simplecsv.processor.ParseError
-
Line from the input that generated the error.
- getLineCount() - Method in class com.j256.simplecsv.processor.BufferedReaderLineCounter
-
Return how many times the
BufferedReaderLineCounter.readLine()method was called. - getLineNumber() - Method in class com.j256.simplecsv.processor.ParseError
-
Line number in the input file that generated the error.
- getLinePos() - Method in class com.j256.simplecsv.processor.ParseError
-
Line position in the input line where the parse error occurred, if any.
- getMessage() - Method in class com.j256.simplecsv.processor.ParseError
-
Return a string message providing details about the error.
- getPosition() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Returns the position the column appears in the file.
- getSetMethod() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Associated reflection set method or null if using field.
- getSingleton() - Static method in class com.j256.simplecsv.converter.BigDecimalConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.BigIntegerConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.BooleanConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.ByteConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.CharacterConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.DateConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.DoubleConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.EnumConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.FloatConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.IntegerConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.LongConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.ShortConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.StringConverter
-
Get singleton for class.
- getSingleton() - Static method in class com.j256.simplecsv.converter.UuidConverter
-
Get singleton for class.
- getType() - Method in class com.j256.simplecsv.processor.ColumnInfo
- getTypeMessage() - Method in enum com.j256.simplecsv.processor.ParseError.ErrorType
- getValue(Object) - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Get the value associated with this field from the object parameter either by getting from the field or calling the get method.
I
- initialize() - Method in class com.j256.simplecsv.processor.CsvProcessor
-
This initializing the internal configuration information.
- IntegerConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java Integer type.
- IntegerConverter() - Constructor for class com.j256.simplecsv.converter.IntegerConverter
- INTERNAL_ERROR - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
internal error was encountered
- INVALID_ENTITY - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
entity validation failed
- INVALID_FORMAT - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
column is in an invalid format
- INVALID_HEADER - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
header line seems to be invalid
- INVALID_NULL - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
null value for this field is invalid
- isAlwaysTrimInput() - Method in class com.j256.simplecsv.converter.AbstractNumberConverter
- isAlwaysTrimInput() - Method in class com.j256.simplecsv.converter.BigDecimalConverter
- isAlwaysTrimInput() - Method in class com.j256.simplecsv.converter.BigIntegerConverter
- isAlwaysTrimInput() - Method in class com.j256.simplecsv.converter.BooleanConverter
- isAlwaysTrimInput() - Method in class com.j256.simplecsv.converter.CharacterConverter
- isAlwaysTrimInput() - Method in interface com.j256.simplecsv.converter.Converter
-
Returns true if the field should trim the string before it is passed to
Converter.stringToJava(String, int, int, ColumnInfo, String, ParseError). - isAlwaysTrimInput() - Method in class com.j256.simplecsv.converter.DateConverter
- isAlwaysTrimInput() - Method in class com.j256.simplecsv.converter.EnumConverter
- isAlwaysTrimInput() - Method in class com.j256.simplecsv.converter.StringConverter
- isAlwaysTrimInput() - Method in class com.j256.simplecsv.converter.UuidConverter
- isAlwaysTrimInput() - Method in class com.j256.simplecsv.converter.VoidConverter
- isError() - Method in class com.j256.simplecsv.processor.ParseError
-
Returns true if the error-type is not
ParseError.ErrorType.NONE. - isMustBeSupplied() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Returns whether the column is optional or not.
- isMustNotBeBlank() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Returns whether this column is required.
- isNeedsQuotes() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Returns whether this column should be surrounded by quotes or not.
- isNeedsQuotes(C) - Method in interface com.j256.simplecsv.converter.Converter
-
Returns true if the field needs to be quoted in the CSV output.
- isNeedsQuotes(BooleanConverter.ConfigInfo) - Method in class com.j256.simplecsv.converter.BooleanConverter
- isNeedsQuotes(EnumConverter.ConfigInfo) - Method in class com.j256.simplecsv.converter.EnumConverter
- isNeedsQuotes(StringConverter.ConfigInfo) - Method in class com.j256.simplecsv.converter.StringConverter
- isNeedsQuotes(Boolean) - Method in class com.j256.simplecsv.converter.CharacterConverter
- isNeedsQuotes(String) - Method in class com.j256.simplecsv.converter.DateConverter
- isNeedsQuotes(Void) - Method in class com.j256.simplecsv.converter.UuidConverter
- isNeedsQuotes(Void) - Method in class com.j256.simplecsv.converter.VoidConverter
- isNeedsQuotes(DecimalFormat) - Method in class com.j256.simplecsv.converter.AbstractNumberConverter
- isNeedsQuotes(DecimalFormat) - Method in class com.j256.simplecsv.converter.BigDecimalConverter
- isNeedsQuotes(DecimalFormat) - Method in class com.j256.simplecsv.converter.BigIntegerConverter
- isTrimInput() - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Returns whether this column should be trimmed when read.
J
- javaToString(ColumnInfo, Boolean) - Method in class com.j256.simplecsv.converter.BooleanConverter
- javaToString(ColumnInfo, Character) - Method in class com.j256.simplecsv.converter.CharacterConverter
- javaToString(ColumnInfo, Enum) - Method in class com.j256.simplecsv.converter.EnumConverter
- javaToString(ColumnInfo, String) - Method in class com.j256.simplecsv.converter.StringConverter
- javaToString(ColumnInfo, Void) - Method in class com.j256.simplecsv.converter.VoidConverter
- javaToString(ColumnInfo, BigDecimal) - Method in class com.j256.simplecsv.converter.BigDecimalConverter
- javaToString(ColumnInfo, BigInteger) - Method in class com.j256.simplecsv.converter.BigIntegerConverter
- javaToString(ColumnInfo, Date) - Method in class com.j256.simplecsv.converter.DateConverter
- javaToString(ColumnInfo, UUID) - Method in class com.j256.simplecsv.converter.UuidConverter
- javaToString(ColumnInfo, T) - Method in class com.j256.simplecsv.converter.AbstractNumberConverter
- javaToString(ColumnInfo, T) - Method in interface com.j256.simplecsv.converter.Converter
-
Converts from a Java representation to string.
L
- LongConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java Long type.
- LongConverter() - Constructor for class com.j256.simplecsv.converter.LongConverter
M
- matchesColumnName(String, String) - Method in interface com.j256.simplecsv.processor.ColumnNameMatcher
-
Returns true if the definition from the
CsvColumnannotation matches the name from the CSV file. - MUST_NOT_BE_BLANK - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
field must not be blank and no data specified
- mustBeSupplied() - Element in annotation type com.j256.simplecsv.common.CsvColumn
-
Set to false if a column is optional and can be skipped in the input altogether.
- mustBeSupplied() - Element in annotation type com.j256.simplecsv.common.CsvField
-
Deprecated.Set to false if a column is optional and can be skipped in the input altogether.
- mustNotBeBlank() - Element in annotation type com.j256.simplecsv.common.CsvColumn
-
Set to true if a value in the column cannot be empty when it is being read in and a parse error or exception will be generated.
- mustNotBeBlank() - Element in annotation type com.j256.simplecsv.common.CsvField
-
Deprecated.Set to true if a value in the column cannot be empty when it is being read in and a parse error or exception will be generated.
N
- NEEDS_QUOTES - Static variable in class com.j256.simplecsv.converter.BooleanConverter
-
Set this flag using
CsvColumn.converterFlags()if you want the output to be surrounded by quotes. - NO_HEADER - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
no header line read
- NONE - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
no error
- numberToValue(Number) - Method in class com.j256.simplecsv.converter.AbstractNumberConverter
-
Convert a number to the appropriate Java type.
- numberToValue(Number) - Method in class com.j256.simplecsv.converter.ByteConverter
- numberToValue(Number) - Method in class com.j256.simplecsv.converter.DoubleConverter
- numberToValue(Number) - Method in class com.j256.simplecsv.converter.FloatConverter
- numberToValue(Number) - Method in class com.j256.simplecsv.converter.IntegerConverter
- numberToValue(Number) - Method in class com.j256.simplecsv.converter.LongConverter
- numberToValue(Number) - Method in class com.j256.simplecsv.converter.ShortConverter
P
- PARSE_ERROR_IF_MORE_THAN_ONE_CHAR - Static variable in class com.j256.simplecsv.converter.CharacterConverter
-
Use this flag if you want a parse error generated when the input has more than one character.
- PARSE_ERROR_ON_INVALID_VALUE - Static variable in class com.j256.simplecsv.converter.BooleanConverter
-
Set this flag using
CsvColumn.converterFlags()if you want a parse error to be generated if the value is not either false or true (or the ones specified in the format). - ParseError - Class in com.j256.simplecsv.processor
-
Used to report back with any parsing or internal errors.
- ParseError() - Constructor for class com.j256.simplecsv.processor.ParseError
- ParseError.ErrorType - Enum in com.j256.simplecsv.processor
-
The type of the error.
- parseString(String) - Method in class com.j256.simplecsv.converter.AbstractNumberConverter
-
Parse a string into the appropriate Java type.
- parseString(String) - Method in class com.j256.simplecsv.converter.ByteConverter
- parseString(String) - Method in class com.j256.simplecsv.converter.DoubleConverter
- parseString(String) - Method in class com.j256.simplecsv.converter.FloatConverter
- parseString(String) - Method in class com.j256.simplecsv.converter.IntegerConverter
- parseString(String) - Method in class com.j256.simplecsv.converter.LongConverter
- parseString(String) - Method in class com.j256.simplecsv.converter.ShortConverter
- processHeader(String, ParseError) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Process a header line and divide it up into a series of quoted columns.
- processRow(String, ParseError) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Read and process a line and return the associated entity.
R
- readAll(File, Collection) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Read in all of the entities in the file passed in.
- readAll(Reader, Collection) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Read in all of the entities in the reader passed in.
- readAll(String, Collection) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Read in all of the entities in the file passed in.
- readHeader(BufferedReader, ParseError) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Read in a line and process it as a CSV header.
- readLine() - Method in class com.j256.simplecsv.processor.BufferedReaderLineCounter
- readRow(BufferedReader, ParseError) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Read an entity line from the reader.
- readRows(BufferedReader, Collection) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Read in all of the entities in the reader passed in but without the header.
- registerConverter(Class, Converter) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Register a converter class for all instances of the class argument.
- reset() - Method in class com.j256.simplecsv.processor.ParseError
-
Resets all of the fields to non-error status.
- RowValidator<T> - Interface in com.j256.simplecsv.processor
-
Row validator callback that can be registered with the
CsvProcessor.setRowValidator(RowValidator)that validates the entity _after_ it has been parsed from the CSV line.
S
- setAllowLineTerminationInColumns(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true to allow line-termination characters inside of a column.
- setAllowPartialLines(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true to allow lines that do not have values for all of the columns.
- setAlwaysTrimInput(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true to always call
String.trim()on data input columns to remove any spaces from the start or end. - setColumnName(String) - Method in class com.j256.simplecsv.processor.ParseError
- setColumnNameMatcher(ColumnNameMatcher) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set the column name matcher class which will be used to see if the column from the CSV file matches the definition name.
- setColumnQuote(char) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Quote character that is used to wrap each column.
- setColumnSeparator(char) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
String that separates columns in out CSV input and output.
- setColumnType(Class) - Method in class com.j256.simplecsv.processor.ParseError
- setColumnValue(String) - Method in class com.j256.simplecsv.processor.ParseError
- setConstructorCallable(Callable) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set the a method that will construct the entity we are loading.
- setEntityClass(Class) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Class that we are processing.
- setErrorType(ParseError.ErrorType) - Method in class com.j256.simplecsv.processor.ParseError
- setFirstLineHeader(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to false if the first line is a header line to be processed.
- setFlexibleOrder(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true if the order of the input columns is flexible and does not have to match the order of the definition fields in the entity.
- setHeaderValidation(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to false to not validate the header when it is read in.
- setIgnoreUnknownColumns(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true to ignore columns that are not know to the configuration.
- setLine(String) - Method in class com.j256.simplecsv.processor.ParseError
- setLineNumber(int) - Method in class com.j256.simplecsv.processor.ParseError
- setLinePos(int) - Method in class com.j256.simplecsv.processor.ParseError
- setLineTermination(String) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Sets the character which is written at the end of the row.
- setMessage(String) - Method in class com.j256.simplecsv.processor.ParseError
- setPosition(int) - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Set the position the column appears in the file.
- setRowValidator(RowValidator) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set the validator which will validate each entity after it has been parsed.
- setSuperClassColumnsFirst(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true to mean that the fields discovered in the superclass come _before_ the sub-classes.
- setValue(Object, T) - Method in class com.j256.simplecsv.processor.ColumnInfo
-
Set the value associated with this field from the object parameter either by setting via the field or calling the set method.
- ShortConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java Short type.
- ShortConverter() - Constructor for class com.j256.simplecsv.converter.ShortConverter
- StringConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java String type.
- StringConverter() - Constructor for class com.j256.simplecsv.converter.StringConverter
- stringToJava(String, int, int, ColumnInfo, String, ParseError) - Method in class com.j256.simplecsv.converter.BooleanConverter
- stringToJava(String, int, int, ColumnInfo, String, ParseError) - Method in class com.j256.simplecsv.converter.CharacterConverter
- stringToJava(String, int, int, ColumnInfo, String, ParseError) - Method in class com.j256.simplecsv.converter.EnumConverter
- stringToJava(String, int, int, ColumnInfo, String, ParseError) - Method in class com.j256.simplecsv.converter.StringConverter
- stringToJava(String, int, int, ColumnInfo, String, ParseError) - Method in class com.j256.simplecsv.converter.VoidConverter
- stringToJava(String, int, int, ColumnInfo, String, ParseError) - Method in class com.j256.simplecsv.converter.BigDecimalConverter
- stringToJava(String, int, int, ColumnInfo, String, ParseError) - Method in class com.j256.simplecsv.converter.BigIntegerConverter
- stringToJava(String, int, int, ColumnInfo, String, ParseError) - Method in class com.j256.simplecsv.converter.DateConverter
- stringToJava(String, int, int, ColumnInfo, String, ParseError) - Method in class com.j256.simplecsv.converter.UuidConverter
- stringToJava(String, int, int, ColumnInfo, String, ParseError) - Method in class com.j256.simplecsv.converter.AbstractNumberConverter
- stringToJava(String, int, int, ColumnInfo, String, ParseError) - Method in interface com.j256.simplecsv.converter.Converter
-
Converts from a string representation to Java.
T
- TOO_MANY_COLUMNS - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
line seems to have extra columns
- toString() - Method in class com.j256.simplecsv.processor.ColumnInfo
- toString() - Method in class com.j256.simplecsv.processor.ParseError
- TRIM_OUTPUT - Static variable in class com.j256.simplecsv.converter.StringConverter
-
If enabled, trim() to be called on the string before it is printed.
- trimInput() - Element in annotation type com.j256.simplecsv.common.CsvColumn
-
Set to true if you want the column read from the line to be trimmed (using
String.trim()) before it is converted to Java. - trimInput() - Element in annotation type com.j256.simplecsv.common.CsvField
-
Deprecated.Set to true if you want the column read from the line to be trimmed (using
String.trim()) before it is converted to Java. - TRUNCATED_COLUMN - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
column seems to be truncated
- TRUNCATED_LINE - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
line seems to be truncated
U
- UNKNOWN_VALUE - Enum constant in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
unknown entity value
- UuidConverter - Class in com.j256.simplecsv.converter
-
Converter for the Java UUID type.
- UuidConverter() - Constructor for class com.j256.simplecsv.converter.UuidConverter
V
- validateHeader(String, ParseError) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Validate the header row against the configured header columns.
- validateHeaderColumns(String[], ParseError) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Validate header columns returned by
CsvProcessor.processHeader(String, ParseError). - validateRow(String, int, T, ParseError) - Method in interface com.j256.simplecsv.processor.RowValidator
-
Validate an entity that was parsed from the line at line-number.
- valueOf(String) - Static method in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
Returns the enum constant of this type with the specified name.
- values() - Static method in enum com.j256.simplecsv.processor.ParseError.ErrorType
-
Returns an array containing the constants of this enum type, in the order they are declared.
- VoidConverter - Class in com.j256.simplecsv.converter
-
Place holder so we can configure the fields with a default converter.
- VoidConverter() - Constructor for class com.j256.simplecsv.converter.VoidConverter
W
- withAllowLineTerminationInColumns(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true to allow line-termination characters inside of a column.
- withAllowPartialLines(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true to allow lines that do not have values for all of the columns.
- withAlwaysTrimInput(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true to always call
String.trim()on data input columns to remove any spaces from the start or end. - withColumnNameMatcher(ColumnNameMatcher) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set the column name matcher class which will be used to see if the column from the CSV file matches the definition name.
- withColumnQuote(char) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Quote character that is used to wrap each column.
- withColumnSeparator(char) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
String that separates columns in out CSV input and output.
- withConstructorCallable(Callable) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set the a method that will construct the entity we are loading.
- withConverter(Class, Converter) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Register a converter class for all instances of the class argument.
- withEntityClass(Class) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Class that we are processing.
- withFirstLineHeader(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to false if the first line is a header line to be processed.
- withFlexibleOrder(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true if the order of the input columns is flexible and does not have to match the order of the definition fields in the entity.
- withHeaderValidation(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to false to not validate the header when it is read in.
- withIgnoreUnknownColumns(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true to ignore columns that are not know to the configuration.
- withLineTermination(String) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Sets the character which is written at the end of the row.
- withRowValidator(RowValidator) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set the validator which will validate each entity after it has been parsed.
- withSuperClassColumnsFirst(boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Set to true to mean that the fields discovered in the superclass come _before_ the sub-classes.
- writeAll(File, Collection, boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Write a collection of entities to the writer.
- writeAll(Writer, Collection, boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Write an optional header and then the collection of entities to the writer.
- writeAll(String, Collection, boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Write a collection of entities to the writer.
- writeHeader(Writer, boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Write the header line to the writer.
- writeRow(Writer, T, boolean) - Method in class com.j256.simplecsv.processor.CsvProcessor
-
Write an entity row to the writer.
All Classes and Interfaces|All Packages|Constant Field Values|Serialized Form
CsvColumnwhich makes more send with get/set method support.